@@ -9,8 +9,7 @@ import django
 from django.conf import settings
 from django.db import transaction
 
-if django.VERSION >= (1, 6):
-    from django.db.transaction import get_connection, atomic
+from django.db.transaction import get_connection, atomic
 
 import djcelery_transactions.transaction_signals
 
@@ -110,28 +109,11 @@ class PostTransactionBatches(Batches):
         eager_transaction = _get_celery_settings('CELERY_EAGER_TRANSACTION',
                                                  not celery_eager)
 
-        if django.VERSION < (1, 6):
-
-            if transaction.is_managed() and eager_transaction:
-                if not transaction.is_dirty():
-                    # Always mark the transaction as dirty
-                    # because we push task in queue that must be fired or discarded
-                    if 'using' in kwargs:
-                        transaction.set_dirty(using=kwargs['using'])
-                    else:
-                        transaction.set_dirty()
-                _get_task_queue().append((self, args, kwargs))
-            else:
-                apply_async_orig = super(PostTransactionTask, self).apply_async
-                return apply_async_orig(*args, **kwargs)
-
+        connection = get_connection()
+        if connection.in_atomic_block and eager_transaction:
+            _get_task_queue().append((self, args, kwargs))
         else:
-
-            connection = get_connection()
-            if connection.in_atomic_block and eager_transaction:
-                _get_task_queue().append((self, args, kwargs))
-            else:
-                return self.original_apply_async(*args, **kwargs)
+            return self.original_apply_async(*args, **kwargs)
 
 def _discard_tasks(**kwargs):
     """Discards all delayed Celery tasks.
@@ -153,13 +135,7 @@ def _send_tasks(**kwargs):
     queue = _get_task_queue()
     while queue:
         tsk, args, kwargs = queue.pop(0)
-        if django.VERSION < (1, 6):
-            apply_async_orig = tsk.original_apply_async
-            if celery_eager:
-                apply_async_orig = transaction.autocommit()(apply_async_orig)
-            apply_async_orig(*args, **kwargs)
-        else:
-            tsk.original_apply_async(*args, **kwargs)
+        tsk.original_apply_async(*args, **kwargs)
 
 
 # A replacement decorator.
